# -*- coding: utf-8 -*-

import datetime

from django.db.models import Q

from kinder.core.direct.models import DRS
from kinder.core.group import GroupStatusEnum, Pupil
from gisdo.utils import DateMixin


def get_193_filter(**kwargs):
    """Фильтр для показателя 19.3
    - направния в статусе "Направлен в ДОУ", "Заключение договора"
    """
    return Q(status__code__in=(DRS.REGISTER, DRS.DOGOVOR))


def get_201_filter(**kwargs):
    """Фильтр для показателя 20.1
    - у ребенка есть зачисление в фактическую группу,
    - не учитываем временно отчисленных
    - у ребенка есть направление в статусах
    "Направлен в ДОУ", "Заключение договора"
    """

    date_border = DateMixin._get_current_calendar_year()

    unit = kwargs.pop("unit")

    children_ids = Pupil.objects.filter(
        grup__status=GroupStatusEnum.FACT,
        temporary_deduct=False
    ).exclude(
        grup__unit_id=unit.id,
    ).values_list('children', flat=True).distinct()

    return Q(
        Q(declaration__children__pupil__temporary_deduct=False,
          declaration__children__pupil__grup__status=GroupStatusEnum.FACT,
          declaration__desired_date__lte=date_border) &
        get_193_filter()
    ) & Q(declaration__children_id__in=children_ids)


def get_34_filter(**kwargs):
    """Фильтр для показателя 34
    - направления в статусе "Направлен в ДОУ", "Заключение договора", "зачислен"
    - дата создания направления: [01.01.2015 - текущая дата],
    т.е текущий календарный год
    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.ACCEPT, DRS.DOGOVOR, DRS.REGISTER],
             date__range=(datetime.date(today_.year, 1, 1), today_))
